@@ -154,11 +154,15 @@ pref("gfx.color_management.display_profile", "");
 pref("gfx.color_management.rendering_intent", 0);
 
 pref("gfx.downloadable_fonts.enabled", true);
+pref("gfx.downloadable_fonts.sanitize", true);
+//@line 162 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", true);
+//@line 164 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 163 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 169 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -171,7 +175,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 179 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 185 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -519,9 +523,9 @@ pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
 pref("content.sink.event_probe_rate", 3);
-//@line 527 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 533 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 529 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 535 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -566,7 +570,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 576 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 582 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -697,6 +701,7 @@ pref("network.IDN.whitelist.es", true);
 pref("network.IDN.whitelist.fi", true);
 pref("network.IDN.whitelist.gr", true);
 pref("network.IDN.whitelist.hu", true);
+pref("network.IDN.whitelist.il", true);
 pref("network.IDN.whitelist.io", true);
 pref("network.IDN.whitelist.ir", true);
 pref("network.IDN.whitelist.is", true);
@@ -720,12 +725,28 @@ pref("network.IDN.whitelist.vn", true);
 // IDN ccTLDs
 // ae, UAE, .<Emarat>
 pref("network.IDN.whitelist.xn--mgbaam7a8h", true); 
-// sa, Saudi Arabia, .<al-Saudiah>
-pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
-// ru, Russian Federation, .<RF>
-pref("network.IDN.whitelist.xn--p1ai", true);
+// cn, China, .<China> with variants
+pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
+pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
+// hk, Hong Kong, .<Hong Kong>
+pref("network.IDN.whitelist.xn--j6w193g", true);
+// ir, Iran, <.Iran> with variants
+pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
+pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// qa, Qatar, .<Qatar>
+pref("network.IDN.whitelist.xn--wgbl6a", true);
+// ru, Russian Federation, .<RF>
+pref("network.IDN.whitelist.xn--p1ai", true);
+// sa, Saudi Arabia, .<al-Saudiah> with variants
+pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
+pref("network.IDN.whitelist.xn--mgberp4a5d4a87g", true);
+pref("network.IDN.whitelist.xn--mgbqly7c0a67fbc", true);
+pref("network.IDN.whitelist.xn--mgbqly7cvafr", true);
+// tw, Taiwan, <.Taiwan> with variants
+pref("network.IDN.whitelist.xn--kpry57d", true);  // Traditional
+pref("network.IDN.whitelist.xn--kprw13d", true);  // Simplified
 
 // gTLDs
 pref("network.IDN.whitelist.biz", true);
@@ -813,7 +834,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 828 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 851 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -832,9 +853,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 848 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 871 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 855 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 878 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1196,15 +1217,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1595 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 1618 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2012 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2035 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2213 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2236 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2307 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2330 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2310 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2333 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1472,20 +1493,20 @@ pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER
 // So, we have no reasons we should use non-toplevel window for popup.
 pref("ui.panel.default_level_parent", true);
 
-//@line 2580 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2603 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2648 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2671 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2674 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2697 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2694 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2717 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2696 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2719 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 pref("print.postscript.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 pref("print.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 
-//@line 2702 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2725 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1509,7 +1530,7 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2731 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2754 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
